Index: /utils/CI/sette_ticket2459/all_functions.sh
===================================================================
--- /utils/CI/sette_ticket2459/all_functions.sh	(revision 12887)
+++ /utils/CI/sette_ticket2459/all_functions.sh	(revision 12888)
@@ -129,5 +129,5 @@
          # rsync keep preserve the modification time stamp.
          # To avoid case where a file in MY_SRC is replace by an older file, we touch the file
-         touch $lCFG/MY_SRC/*
+         touch --no-create $lCFG/MY_SRC/*
       fi
 
Index: ils/CI/sette_ticket2459/input_SPITZ12.cfg
===================================================================
--- /utils/CI/sette_ticket2459/input_SPITZ12.cfg	(revision 12887)
+++ 	(revision )
@@ -1,1 +1,0 @@
-SPITZ12_v4.0.tar SPITZ12_v4.0
Index: /utils/CI/sette_ticket2459/input_WED025.cfg
===================================================================
--- /utils/CI/sette_ticket2459/input_WED025.cfg	(revision 12888)
+++ /utils/CI/sette_ticket2459/input_WED025.cfg	(revision 12888)
@@ -0,0 +1,1 @@
+WED025_v4.2.tar WED025_v4.2
Index: /utils/CI/sette_ticket2459/param.cfg
===================================================================
--- /utils/CI/sette_ticket2459/param.cfg	(revision 12887)
+++ /utils/CI/sette_ticket2459/param.cfg	(revision 12888)
@@ -74,5 +74,5 @@
 # LIST OF CONFIGURATIONS
 # to be updated if you added an new configuration in sette_test-cases.sh or sette_reference-configuration.sh
-TEST_CONFIGS=${SETTE_TEST_CONFIGS:-"ORCA2_ICE_PISCES ORCA2_OFF_PISCES AMM12 AGRIF SPITZ12 GYRE_PISCES SAS ORCA2_ICE_OBS ICE_AGRIF OVERFLOW LOCK_EXCHANGE VORTEX ISOMIP+"}
+TEST_CONFIGS=${SETTE_TEST_CONFIGS:-"ORCA2_ICE_PISCES ORCA2_OFF_PISCES AMM12 AGRIF WED025 GYRE_PISCES SAS ORCA2_ICE_OBS ICE_AGRIF OVERFLOW LOCK_EXCHANGE VORTEX ISOMIP+"}
 # ------------------------------------------------------------------------------------------
 #
Index: /utils/CI/sette_ticket2459/sette_list_avail_cfg.sh
===================================================================
--- /utils/CI/sette_ticket2459/sette_list_avail_cfg.sh	(revision 12887)
+++ /utils/CI/sette_ticket2459/sette_list_avail_cfg.sh	(revision 12888)
@@ -9,5 +9,5 @@
 printf "%-15s \n" ORCA2_ICE_OBS
 printf "%-15s \n" AGRIF
-printf "%-15s \n" SPITZ12
+printf "%-15s \n" WED025
 echo ''
 echo 'Test cases available are named :'
Index: /utils/CI/sette_ticket2459/sette_rpt.sh
===================================================================
--- /utils/CI/sette_ticket2459/sette_rpt.sh	(revision 12887)
+++ /utils/CI/sette_ticket2459/sette_rpt.sh	(revision 12888)
@@ -489,5 +489,5 @@
  echo ""
  echo "   !----restart----!   "
- for restart_test in WGYRE_PISCES_ST WORCA2_ICE_PISCES_ST WORCA2_OFF_PISCES_ST WAMM12_ST WORCA2_SAS_ICE_ST WAGRIF_DEMO_ST WSPITZ12_ST WISOMIP+_ST WOVERFLOW_ST WLOCK_EXCHANGE_ST WVORTEX_ST WICE_AGRIF_ST 
+ for restart_test in WGYRE_PISCES_ST WORCA2_ICE_PISCES_ST WORCA2_OFF_PISCES_ST WAMM12_ST WORCA2_SAS_ICE_ST WAGRIF_DEMO_ST WWED025_ST WISOMIP+_ST WOVERFLOW_ST WLOCK_EXCHANGE_ST WVORTEX_ST WICE_AGRIF_ST 
  do
    resttest $NEMO_VALID $restart_test $pass
@@ -497,5 +497,5 @@
  echo ""
  echo "   !----repro----!   "
- for repro_test in WGYRE_PISCES_ST WORCA2_ICE_PISCES_ST WORCA2_OFF_PISCES_ST WAMM12_ST WORCA2_SAS_ICE_ST WORCA2_ICE_OBS_ST WAGRIF_DEMO_ST WSPITZ12_ST WISOMIP+_ST WVORTEX_ST WICE_AGRIF_ST
+ for repro_test in WGYRE_PISCES_ST WORCA2_ICE_PISCES_ST WORCA2_OFF_PISCES_ST WAMM12_ST WORCA2_SAS_ICE_ST WORCA2_ICE_OBS_ST WAGRIF_DEMO_ST WWED025_ST WISOMIP+_ST WVORTEX_ST WICE_AGRIF_ST
  do
    reprotest $NEMO_VALID $repro_test $pass
@@ -524,5 +524,5 @@
      echo "REFERENCE directory : $NEMO_VALID_REF at rev $NEMO_REV_REF"
      echo ''
-     for repro_test in WGYRE_PISCES_ST WORCA2_ICE_PISCES_ST WORCA2_OFF_PISCES_ST WAMM12_ST WISOMIP+_ST WORCA2_SAS_ICE_ST WAGRIF_DEMO_ST WSPITZ12_ST WISOMIP+_ST WVORTEX_ST WICE_AGRIF_ST
+     for repro_test in WGYRE_PISCES_ST WORCA2_ICE_PISCES_ST WORCA2_OFF_PISCES_ST WAMM12_ST WISOMIP+_ST WORCA2_SAS_ICE_ST WAGRIF_DEMO_ST WWED025_ST WISOMIP+_ST WVORTEX_ST WICE_AGRIF_ST
      do
        runcmpres $NEMO_VALID $repro_test $NEMO_VALID_REF $NEMO_REV_REF $pass

Index: /utils/CI/sette_ticket2459/sette_reference-configurations.sh
===================================================================
--- /utils/CI/sette_ticket2459/sette_reference-configurations.sh	(revision 12887)
+++ /utils/CI/sette_ticket2459/sette_reference-configurations.sh	(revision 12888)
@@ -150,5 +150,5 @@
 # AGRIF             : test AGRIF in a double zoom configuration in the nordic seas + 1 zoom in the eq. Pacific (AGRIF_DEMO)
 #                       and check that key_agrif without zoom = no key_agrif
 # SPITZ12           : regional configuration including sea-ice and tides (Spitzbergen)
 
 for config in ${TEST_CONFIGS}
@@ -1380,7 +1380,7 @@
 
 # -------
-# SPITZ12
+# WED025
 # -------
-if [ ${config} == "SPITZ12" ] ;  then
+if [ ${config} == "WED025" ] ;  then
 ## Restartability tests
     export TEST_NAME="LONG"
@@ -1389,23 +1389,23 @@
     # syncronisation if target directory/file exist (not done by makenemo)
     . ${SETTE_DIR}/all_functions.sh
-    sync_config  SPITZ12 SPITZ12_ST 'cfgs'
-    clean_config SPITZ12 SPITZ12_ST 'cfgs'
-    #
-    . ./makenemo -m ${CMP_NAM} -n SPITZ12_ST -r SPITZ12 -j 8 add_key "${ADD_KEYS}" del_key "${DEL_KEYS}"
-    cd ${SETTE_DIR}
-    . ./param.cfg
-    . ./all_functions.sh
-    . ./prepare_exe_dir.sh
-    set_valid_dir
-    clean_valid_dir
-    JOB_FILE=${EXE_DIR}/run_job.sh
-    NPROC=32
-    if [ -f ${JOB_FILE} ] ; then \rm ${JOB_FILE} ; fi
-    cd ${EXE_DIR}
-    set_namelist namelist_cfg cn_exp \"S12_LONG\"
-    set_namelist namelist_cfg nn_it000 1
-    set_namelist namelist_cfg nn_itend 240
-    set_namelist namelist_cfg nn_stock 120
-    set_namelist namelist_cfg nn_date0 20020101
+    sync_config  WED025 WED025_ST 'cfgs'
+    clean_config WED025 WED025_ST 'cfgs'
+    #
+    . ./makenemo -m ${CMP_NAM} -n WED025_ST -r WED025 -j 8 add_key "${ADD_KEYS}" del_key "${DEL_KEYS}"
+    cd ${SETTE_DIR}
+    . ./param.cfg
+    . ./all_functions.sh
+    . ./prepare_exe_dir.sh
+    set_valid_dir
+    clean_valid_dir
+    JOB_FILE=${EXE_DIR}/run_job.sh
+    NPROC=32
+    if [ -f ${JOB_FILE} ] ; then \rm ${JOB_FILE} ; fi
+    cd ${EXE_DIR}
+    set_namelist namelist_cfg cn_exp \"WED025_LONG\"
+    set_namelist namelist_cfg nn_it000 1
+    set_namelist namelist_cfg nn_itend 720
+    set_namelist namelist_cfg nn_stock 360
+    set_namelist namelist_cfg nn_date0 20000115
     set_namelist namelist_cfg jpni 4
     set_namelist namelist_cfg jpnj 8
@@ -1419,5 +1419,5 @@
     fi
     cd ${SETTE_DIR}
-    . ./prepare_job.sh input_SPITZ12.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS} ${NEMO_VALID}
+    . ./prepare_job.sh input_WED025.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS} ${NEMO_VALID}
     
     cd ${SETTE_DIR}
@@ -1427,8 +1427,8 @@
     clean_valid_dir
     cd ${EXE_DIR}
-    set_namelist namelist_cfg cn_exp \"S12_SHORT\"
-    set_namelist namelist_cfg nn_it000 121
-    set_namelist namelist_cfg nn_itend 240
-    set_namelist namelist_cfg nn_stock 120
+    set_namelist namelist_cfg cn_exp \"WED025_SHORT\"
+    set_namelist namelist_cfg nn_it000 361
+    set_namelist namelist_cfg nn_itend 720
+    set_namelist namelist_cfg nn_stock 360
     set_namelist namelist_cfg ln_rstart .true.
     set_namelist namelist_cfg nn_rstctl 2
@@ -1437,11 +1437,11 @@
     set_namelist namelist_cfg sn_cfctl%l_config .true.
     set_namelist namelist_cfg sn_cfctl%l_runstat .true.
-    set_namelist namelist_cfg cn_ocerst_in \"S12_LONG_00000120_restart\"
-    set_namelist namelist_ice_cfg cn_icerst_in \"S12_LONG_00000120_restart_ice\"
+    set_namelist namelist_cfg cn_ocerst_in \"WED025_LONG_00000360_restart\"
+    set_namelist namelist_ice_cfg cn_icerst_in \"WED025_LONG_00000360_restart_ice\"
     for (( i=1; i<=$NPROC; i++)) ; do
         L_NPROC=$(( $i - 1 ))
         L_NPROC=`printf "%04d\n" ${L_NPROC}`
-        ln -sf ../LONG/S12_LONG_00000120_restart_${L_NPROC}.nc .
-        ln -sf ../LONG/S12_LONG_00000120_restart_ice_${L_NPROC}.nc .
+        ln -sf ../LONG/WED025_LONG_00000360_restart_${L_NPROC}.nc .
+        ln -sf ../LONG/WED025_LONG_00000360_restart_ice_${L_NPROC}.nc .
     done
     if [ ${USING_MPMD} == "yes" ] ; then
@@ -1451,36 +1451,36 @@
     fi
     cd ${SETTE_DIR}
-    . ./prepare_job.sh input_SPITZ12.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS} ${NEMO_VALID}
+    . ./prepare_job.sh input_WED025.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS} ${NEMO_VALID}
     cd ${SETTE_DIR}
     . ./fcm_job.sh $NPROC ${JOB_FILE} ${INTERACT_FLAG} ${MPIRUN_FLAG}
 
 ## Reproducibility tests
-    export TEST_NAME="REPRO_4_8"
-    cd ${MAIN_DIR}
-    cd ${SETTE_DIR}
-    . ./param.cfg
-    . ./all_functions.sh
-    . ./prepare_exe_dir.sh
-    set_valid_dir
-    clean_valid_dir
-    JOB_FILE=${EXE_DIR}/run_job.sh
-    NPROC=32
-    if [ -f ${JOB_FILE} ] ; then \rm ${JOB_FILE} ; fi
-    cd ${EXE_DIR}
-    set_namelist namelist_cfg cn_exp \"S12_48\"
-    set_namelist namelist_cfg nn_it000 1
-    set_namelist namelist_cfg nn_itend 120
-    set_namelist namelist_cfg nn_date0 20020101
-    set_namelist namelist_cfg jpni 4
-    set_namelist namelist_cfg jpnj 8
-    set_namelist namelist_cfg sn_cfctl%l_config .true.
-    set_namelist namelist_cfg sn_cfctl%l_runstat .true.
-    if [ ${USING_MPMD} == "yes" ] ; then
-       set_xio_using_server iodef.xml true
-    else
-       set_xio_using_server iodef.xml false
-    fi
-    cd ${SETTE_DIR}
-    . ./prepare_job.sh input_SPITZ12.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS} ${NEMO_VALID}
+    export TEST_NAME="REPRO_5_6"
+    cd ${MAIN_DIR}
+    cd ${SETTE_DIR}
+    . ./param.cfg
+    . ./all_functions.sh
+    . ./prepare_exe_dir.sh
+    set_valid_dir
+    clean_valid_dir
+    JOB_FILE=${EXE_DIR}/run_job.sh
+    NPROC=32
+    if [ -f ${JOB_FILE} ] ; then \rm ${JOB_FILE} ; fi
+    cd ${EXE_DIR}
+    set_namelist namelist_cfg cn_exp \"WED025_56\"
+    set_namelist namelist_cfg nn_it000 1
+    set_namelist namelist_cfg nn_itend 720
+    set_namelist namelist_cfg nn_date0 20000115
+    set_namelist namelist_cfg jpni 6
+    set_namelist namelist_cfg jpnj 7
+    set_namelist namelist_cfg sn_cfctl%l_config .true.
+    set_namelist namelist_cfg sn_cfctl%l_runstat .true.
+    if [ ${USING_MPMD} == "yes" ] ; then
+       set_xio_using_server iodef.xml true
+    else
+       set_xio_using_server iodef.xml false
+    fi
+    cd ${SETTE_DIR}
+    . ./prepare_job.sh input_WED025.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS} ${NEMO_VALID}
     cd ${SETTE_DIR}
     . ./fcm_job.sh $NPROC ${JOB_FILE} ${INTERACT_FLAG} ${MPIRUN_FLAG}
@@ -1495,8 +1495,8 @@
     if [ -f ${JOB_FILE} ] ; then \rm ${JOB_FILE} ; fi
     cd ${EXE_DIR}
-    set_namelist namelist_cfg cn_exp \"S12_84\"
-    set_namelist namelist_cfg nn_it000 1
-    set_namelist namelist_cfg nn_itend 120
-    set_namelist namelist_cfg nn_date0 20020101
+    set_namelist namelist_cfg cn_exp \"WED025_84\"
+    set_namelist namelist_cfg nn_it000 1
+    set_namelist namelist_cfg nn_itend 720
+    set_namelist namelist_cfg nn_date0 20000115
     set_namelist namelist_cfg jpni 8
     set_namelist namelist_cfg jpnj 4
@@ -1509,5 +1509,5 @@
     fi
     cd ${SETTE_DIR}
-    . ./prepare_job.sh input_SPITZ12.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS} ${NEMO_VALID}
+    . ./prepare_job.sh input_WED025.cfg $NPROC ${TEST_NAME} ${MPIRUN_FLAG} ${JOB_FILE} ${NUM_XIOSERVERS} ${NEMO_VALID}
     cd ${SETTE_DIR}
     . ./fcm_job.sh $NPROC ${JOB_FILE} ${INTERACT_FLAG} ${MPIRUN_FLAG}
@@ -150,5 +150,5 @@
 # AGRIF             : test AGRIF in a double zoom configuration in the nordic seas + 1 zoom in the eq. Pacific (AGRIF_DEMO)
 #                       and check that key_agrif without zoom = no key_agrif
-# SPITZ12           : regional configuration including sea-ice and tides (Spitzbergen)
+# WED025           : regional configuration including sea-ice and tides (Spitzbergen)
 
 for config in ${TEST_CONFIGS}